@@ -1,5 +1,5 @@
 //
-// Copyright (c) 2021 Red Hat, Inc.
+// Copyright (c) 2019-2021 Red Hat, Inc.
 // This program and the accompanying materials are made
 // available under the terms of the Eclipse Public License 2.0
 // which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -48,7 +48,7 @@ func NewBackupContext(r *ReconcileCheClusterBackup, backupCR *chev1.CheClusterBa
 		// After the preparations, a new reconcile loop will be triggered, so backupServer will not be nil any more.
 	}
 
-	cheCR, _, err := util.FindCheClusterCRInNamespace(r.client, namespace)
+	cheCR, _, err := util.FindCheClusterCRInNamespace(r.cachingClient, namespace)
 	if err != nil {
 		return nil, err
 	}
