@@ -19,6 +19,8 @@ import (
 	"strconv"
 	"strings"
 
+	"k8s.io/utils/pointer"
+
 	"github.com/eclipse-che/che-operator/pkg/util"
 
 	"github.com/eclipse-che/che-operator/pkg/deploy/gateway"
@@ -449,14 +451,14 @@ func provisionMainWorkspaceRoute(cheCluster *v2alpha1.CheCluster, routing *dwo.D
 		// on OpenShift, we need to set authorization header.
 		// This MUST come before Auth, because Auth needs Authorization header to be properly set.
 		cfg.AddAuthHeaderRewrite(dwId)
-
-		// authorize against kube-rbac-proxy in che-gateway. This will be needed for k8s native auth as well.
-		cfg.AddAuth(dwId, "http://127.0.0.1:8089?namespace="+dwNamespace)
-
-		// make '/healthz' path of main endpoints reachable from outside
-		routeForHealthzEndpoint(cfg, dwId, routing.Spec.Endpoints)
 	}
 
+	// authorize against kube-rbac-proxy in che-gateway. This will be needed for k8s native auth as well.
+	cfg.AddAuth(dwId, "http://127.0.0.1:8089?namespace="+dwNamespace)
+
+	// make '/healthz' path of main endpoints reachable from outside
+	routeForHealthzEndpoint(cfg, dwId, routing.Spec.Endpoints)
+
 	if contents, err := yaml.Marshal(cfg); err != nil {
 		return nil, err
 	} else {
@@ -514,13 +516,10 @@ func addEndpointToTraefikConfig(componentName string, e dw.Endpoint, cfg *gatewa
 		100,
 		fmt.Sprintf("http://127.0.0.1:%d", e.TargetPort),
 		[]string{prefix})
-	if util.IsOpenShift4 {
-		cfg.AddAuth(name, fmt.Sprintf("http://%s.%s:8089?namespace=%s", gateway.GatewayServiceName, cheCluster.Namespace, routing.Namespace))
-	}
+	cfg.AddAuth(name, fmt.Sprintf("http://%s.%s:8089?namespace=%s", gateway.GatewayServiceName, cheCluster.Namespace, routing.Namespace))
 
 	// we need to disable auth for '/healthz' path in main endpoint, for now only on OpenShift
-	if util.IsOpenShift4 &&
-		e.Attributes.GetString(string(dwo.TypeEndpointAttribute), nil) == string(dwo.MainEndpointType) {
+	if e.Attributes.GetString(string(dwo.TypeEndpointAttribute), nil) == string(dwo.MainEndpointType) {
 		healthzName := name + "-healthz"
 		healthzPath := prefix + "/healthz"
 		cfg.AddComponent(
@@ -675,7 +674,7 @@ func determineEndpointScheme(e dw.Endpoint) string {
 		scheme = string(e.Protocol)
 	}
 
-	upgradeToSecure := e.Secure
+	upgradeToSecure := pointer.BoolPtrDerefOr(e.Secure, false)
 
 	// gateway is always on HTTPS, so if the endpoint is served through the gateway, we need to use the TLS'd variant.
 	if e.Attributes.GetString(urlRewriteSupportedEndpointAttributeName, nil) == "true" {
