@@ -15,6 +15,7 @@ import (
 	"testing"
 
 	"github.com/eclipse-che/che-operator/pkg/deploy"
+	"github.com/stretchr/testify/assert"
 	corev1 "k8s.io/api/core/v1"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"k8s.io/apimachinery/pkg/runtime"
@@ -69,14 +70,11 @@ func TestNewCheConfigMap(t *testing.T) {
 		t.Run(testCase.name, func(t *testing.T) {
 			util.IsOpenShift = testCase.isOpenShift
 			util.IsOpenShift4 = testCase.isOpenShift4
-			deployContext := deploy.GetTestDeployContext(testCase.cheCluster, []runtime.Object{})
-
-			server := NewServer(deployContext)
-			actualData, err := server.getCheConfigMapData()
-			if err != nil {
-				t.Fatalf("Error creating ConfigMap data: %v", err)
-			}
+			ctx := deploy.GetTestDeployContext(testCase.cheCluster, []runtime.Object{})
 
+			server := NewCheServerReconciler()
+			actualData, err := server.getCheConfigMapData(ctx)
+			assert.Nil(t, err)
 			util.ValidateContainData(actualData, testCase.expectedData, t)
 		})
 	}
@@ -225,20 +223,17 @@ func TestConfigMap(t *testing.T) {
 		t.Run(testCase.name, func(t *testing.T) {
 			util.IsOpenShift = testCase.isOpenShift
 			util.IsOpenShift4 = testCase.isOpenShift4
-			deployContext := deploy.GetTestDeployContext(testCase.cheCluster, testCase.initObjects)
-
-			server := NewServer(deployContext)
-			actualData, err := server.getCheConfigMapData()
-			if err != nil {
-				t.Fatalf("Error creating ConfigMap data: %v", err)
-			}
+			ctx := deploy.GetTestDeployContext(testCase.cheCluster, testCase.initObjects)
 
+			server := NewCheServerReconciler()
+			actualData, err := server.getCheConfigMapData(ctx)
+			assert.Nil(t, err)
 			util.ValidateContainData(actualData, testCase.expectedData, t)
 		})
 	}
 }
 
-func TestUpdateBitBucketEndpoints(t *testing.T) {
+func TestUpdateIntegrationServerEndpoints(t *testing.T) {
 	type testCase struct {
 		name         string
 		initObjects  []runtime.Object
@@ -272,6 +267,7 @@ func TestUpdateBitBucketEndpoints(t *testing.T) {
 			cheCluster: &orgv1.CheCluster{
 				ObjectMeta: metav1.ObjectMeta{
 					Namespace: "eclipse-che",
+					Name:      "eclipse-che",
 				},
 			},
 			expectedData: map[string]string{
@@ -303,6 +299,7 @@ func TestUpdateBitBucketEndpoints(t *testing.T) {
 			cheCluster: &orgv1.CheCluster{
 				ObjectMeta: metav1.ObjectMeta{
 					Namespace: "eclipse-che",
+					Name:      "eclipse-che",
 				},
 				Spec: orgv1.CheClusterSpec{
 					Server: orgv1.CheClusterSpecServer{
@@ -313,7 +310,7 @@ func TestUpdateBitBucketEndpoints(t *testing.T) {
 				},
 			},
 			expectedData: map[string]string{
-				"CHE_INTEGRATION_BITBUCKET_SERVER__ENDPOINTS": "bitbucket_endpoint_1,bitbucket_endpoint_2",
+				"CHE_INTEGRATION_BITBUCKET_SERVER__ENDPOINTS": "bitbucket_endpoint_2,bitbucket_endpoint_1",
 			},
 		},
 		{
@@ -339,14 +336,11 @@ func TestUpdateBitBucketEndpoints(t *testing.T) {
 
 	for _, testCase := range testCases {
 		t.Run(testCase.name, func(t *testing.T) {
-			deployContext := deploy.GetTestDeployContext(testCase.cheCluster, testCase.initObjects)
-
-			server := NewServer(deployContext)
-			actualData, err := server.getCheConfigMapData()
-			if err != nil {
-				t.Fatalf("Error creating ConfigMap data: %v", err)
-			}
+			ctx := deploy.GetTestDeployContext(testCase.cheCluster, testCase.initObjects)
 
+			server := NewCheServerReconciler()
+			actualData, err := server.getCheConfigMapData(ctx)
+			assert.Nil(t, err)
 			util.ValidateContainData(actualData, testCase.expectedData, t)
 		})
 	}
@@ -550,14 +544,11 @@ func TestShouldSetUpCorrectlyDevfileRegistryURL(t *testing.T) {
 		t.Run(testCase.name, func(t *testing.T) {
 			util.IsOpenShift = testCase.isOpenShift
 			util.IsOpenShift4 = testCase.isOpenShift4
-			deployContext := deploy.GetTestDeployContext(testCase.cheCluster, []runtime.Object{})
-
-			server := NewServer(deployContext)
-			actualData, err := server.getCheConfigMapData()
-			if err != nil {
-				t.Fatalf("Error creating ConfigMap data: %v", err)
-			}
+			ctx := deploy.GetTestDeployContext(testCase.cheCluster, []runtime.Object{})
 
+			server := NewCheServerReconciler()
+			actualData, err := server.getCheConfigMapData(ctx)
+			assert.Nil(t, err)
 			util.ValidateContainData(actualData, testCase.expectedData, t)
 		})
 	}
@@ -686,14 +677,11 @@ func TestShouldSetUpCorrectlyInternalPluginRegistryServiceURL(t *testing.T) {
 		t.Run(testCase.name, func(t *testing.T) {
 			util.IsOpenShift = testCase.isOpenShift
 			util.IsOpenShift4 = testCase.isOpenShift4
-			deployContext := deploy.GetTestDeployContext(testCase.cheCluster, []runtime.Object{})
-
-			server := NewServer(deployContext)
-			actualData, err := server.getCheConfigMapData()
-			if err != nil {
-				t.Fatalf("Error creating ConfigMap data: %v", err)
-			}
+			ctx := deploy.GetTestDeployContext(testCase.cheCluster, []runtime.Object{})
 
+			server := NewCheServerReconciler()
+			actualData, err := server.getCheConfigMapData(ctx)
+			assert.Nil(t, err)
 			util.ValidateContainData(actualData, testCase.expectedData, t)
 		})
 	}
@@ -763,14 +751,11 @@ func TestShouldSetUpCorrectlyInternalCheServerURL(t *testing.T) {
 		t.Run(testCase.name, func(t *testing.T) {
 			util.IsOpenShift = testCase.isOpenShift
 			util.IsOpenShift4 = testCase.isOpenShift4
-			deployContext := deploy.GetTestDeployContext(testCase.cheCluster, []runtime.Object{})
-
-			server := NewServer(deployContext)
-			actualData, err := server.getCheConfigMapData()
-			if err != nil {
-				t.Fatalf("Error creating ConfigMap data: %v", err)
-			}
+			ctx := deploy.GetTestDeployContext(testCase.cheCluster, []runtime.Object{})
 
+			server := NewCheServerReconciler()
+			actualData, err := server.getCheConfigMapData(ctx)
+			assert.Nil(t, err)
 			util.ValidateContainData(actualData, testCase.expectedData, t)
 		})
 	}
@@ -806,8 +791,8 @@ func TestShouldSetUpCorrectlyInternalIdentityProviderServiceURL(t *testing.T) {
 				},
 			},
 			expectedData: map[string]string{
-				"CHE_KEYCLOAK_AUTH__INTERNAL__SERVER__URL": "",
-				"CHE_KEYCLOAK_AUTH__SERVER__URL":           "http://external-keycloak/auth",
+				"CHE_OIDC_AUTH__INTERNAL__SERVER__URL": "",
+				"CHE_OIDC_AUTH__SERVER__URL":           "http://external-keycloak/auth",
 			},
 		},
 		{
@@ -829,8 +814,8 @@ func TestShouldSetUpCorrectlyInternalIdentityProviderServiceURL(t *testing.T) {
 				},
 			},
 			expectedData: map[string]string{
-				"CHE_KEYCLOAK_AUTH__INTERNAL__SERVER__URL": "",
-				"CHE_KEYCLOAK_AUTH__SERVER__URL":           "http://external-keycloak/auth",
+				"CHE_OIDC_AUTH__INTERNAL__SERVER__URL": "",
+				"CHE_OIDC_AUTH__SERVER__URL":           "http://external-keycloak/auth",
 			},
 		},
 		{
@@ -855,8 +840,8 @@ func TestShouldSetUpCorrectlyInternalIdentityProviderServiceURL(t *testing.T) {
 				},
 			},
 			expectedData: map[string]string{
-				"CHE_KEYCLOAK_AUTH__INTERNAL__SERVER__URL": "",
-				"CHE_KEYCLOAK_AUTH__SERVER__URL":           "http://external-keycloak/auth",
+				"CHE_OIDC_AUTH__INTERNAL__SERVER__URL": "",
+				"CHE_OIDC_AUTH__SERVER__URL":           "http://external-keycloak/auth",
 			},
 		},
 		{
@@ -881,8 +866,8 @@ func TestShouldSetUpCorrectlyInternalIdentityProviderServiceURL(t *testing.T) {
 				},
 			},
 			expectedData: map[string]string{
-				"CHE_KEYCLOAK_AUTH__INTERNAL__SERVER__URL": "",
-				"CHE_KEYCLOAK_AUTH__SERVER__URL":           "http://keycloak/auth",
+				"CHE_OIDC_AUTH__INTERNAL__SERVER__URL": "",
+				"CHE_OIDC_AUTH__SERVER__URL":           "http://keycloak/auth",
 			},
 		},
 		{
@@ -904,8 +889,8 @@ func TestShouldSetUpCorrectlyInternalIdentityProviderServiceURL(t *testing.T) {
 				},
 			},
 			expectedData: map[string]string{
-				"CHE_KEYCLOAK_AUTH__INTERNAL__SERVER__URL": "http://keycloak.eclipse-che.svc:8080/auth",
-				"CHE_KEYCLOAK_AUTH__SERVER__URL":           "http://keycloak/auth",
+				"CHE_OIDC_AUTH__INTERNAL__SERVER__URL": "http://keycloak.eclipse-che.svc:8080/auth",
+				"CHE_OIDC_AUTH__SERVER__URL":           "http://keycloak/auth",
 			},
 		},
 	}
@@ -914,10 +899,10 @@ func TestShouldSetUpCorrectlyInternalIdentityProviderServiceURL(t *testing.T) {
 		t.Run(testCase.name, func(t *testing.T) {
 			util.IsOpenShift = testCase.isOpenShift
 			util.IsOpenShift4 = testCase.isOpenShift4
-			deployContext := deploy.GetTestDeployContext(testCase.cheCluster, []runtime.Object{})
+			ctx := deploy.GetTestDeployContext(testCase.cheCluster, []runtime.Object{})
 
-			server := NewServer(deployContext)
-			actualData, err := server.getCheConfigMapData()
+			server := NewCheServerReconciler()
+			actualData, err := server.getCheConfigMapData(ctx)
 			if err != nil {
 				t.Fatalf("Error creating ConfigMap data: %v", err)
 			}
